"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const hash_sum_1 = tslib_1.__importDefault(require("hash-sum"));
const lru_cache_1 = tslib_1.__importDefault(require("lru-cache"));
const highlight_js_1 = tslib_1.__importDefault(require("highlight.js"));
// markdown-it and plugins
const markdown_it_1 = tslib_1.__importDefault(require("markdown-it"));
const markdown_it_emoji_1 = tslib_1.__importDefault(require("markdown-it-emoji"));
const markdown_it_anchor_1 = tslib_1.__importDefault(require("markdown-it-anchor"));
const markdown_it_table_of_contents_1 = tslib_1.__importDefault(require("markdown-it-table-of-contents"));
const containers_1 = tslib_1.__importDefault(require("./containers"));
const md = markdown_it_1.default({
    html: true,
    highlight: function (str, lang) {
        if (lang && highlight_js_1.default.getLanguage(lang)) {
            try {
                return ('<pre class="hljs"><code>' +
                    highlight_js_1.default.highlight(lang, str, true).value +
                    '</code></pre>');
            }
            catch (__) { }
        }
        return ('<pre v-pre class="hljs"><code>' +
            md.utils.escapeHtml(str) +
            '</code></pre>');
    },
})
    .use(markdown_it_emoji_1.default)
    .use(markdown_it_anchor_1.default, {
    permalink: true,
    permalinkBefore: true,
    permalinkSymbol: '#',
})
    .use(markdown_it_table_of_contents_1.default, {
    includeLevel: [2, 3],
})
    .use(containers_1.default);
const cache = lru_cache_1.default({ max: 1000 });
exports.default = src => {
    const isProd = process.env.NODE_ENV === 'production';
    const file = this.resourcePath;
    const key = hash_sum_1.default(file + src);
    const cached = cache.get(key);
    if (cached && (isProd || /\?vue/.test(this.resourceQuery))) {
        return cached;
    }
    const html = md.render(src);
    const res = `<template>\n` + `<div class="content">${html}</div>\n` + `</template>\n`;
    cache.set(key, res);
    return res;
};
